@@ -1,10 +1,10 @@
 /*
  * @(#)Abacus.h
  *
- * Copyright 1994 - 2014  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2016  David A. Bagley, bagleyd AT verizon.net
  *
  * Abacus demo and neat pointers from
- * Copyright 1991 - 1998  Luis Fernandes, elf@ee.ryerson.ca
+ * Copyright 1991 - 1998  Luis Fernandes, elf AT ee.ryerson.ca
  *
  * All rights reserved.
  *
@@ -204,7 +204,6 @@
 #define XtCLeftAuxAbacus ((char *) "LeftAuxAbacus")
 #define XtCRightAuxAbacus ((char *) "RightAuxAbacus")
 typedef struct _AbacusClassRec *AbacusWidgetClass;
-typedef struct _AbacusDemoClassRec *AbacusDemoWidgetClass;
 
 extern WidgetClass abacusWidgetClass;
 extern WidgetClass abacusDemoWidgetClass;
@@ -342,7 +341,7 @@ typedef struct {
 #define GENERIC 7
 #define MAX_FORMATS 7
 #define MAX_MODES 8
-#define TEACH_STRING0 "Enter calculation X+Y, X-Y, X*Y, X/Y, Xv, or Xu where X positive and result positive."
+#define TEACH_STRING0 "Enter calculation X+Y, X-Y, X*Y, X/Y, Xv, or Xu where X and result nonnegative."
 #define TEACH_STRING1 "Press enter to go through calculation steps."
 #define ZERO_STRING "0.0"
 
