@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusC.c
  *
- * Copyright 1992 - 2012  David A. Bagley, bagleyd@tux.org
+ * Copyright 1992 - 2016  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -223,6 +223,7 @@ static const short unsigned int operationASCII[] =
 /* True for period, +/-, or operator */
 #define IS_VALID(v, b) ((IS_DIGIT(v)) ? (CHAR_TO_DIGIT(v) < b) : True)
 #define MAX_VALUE_LENGTH 64
+#define CALC_STRING_SIZE 256
 
 enum Stackusage {paren, order};
 
@@ -262,9 +263,9 @@ static Boolean negateNext = False; /* handles unary '-' */
 static double left, right; /* sides of a binary operation */
 static char pendingOperation; /* operation to be performed on left (& right if not unary) */
 static Boolean hub; /* intermediate result? usually a ')' or pi pressed */
-static char memoryBuf[256];
-static char displayBuf[256];
-static char stringBuf[256];
+static char memoryBuf[CALC_STRING_SIZE];
+static char displayBuf[CALC_STRING_SIZE];
+static char stringBuf[CALC_STRING_SIZE];
 static int digits = 1;
 static int currentBase = DEFAULT_BASE, currentDigits = DEFAULT_DECIMAL_DIGITS;
 static char decimalPoint = '.';
@@ -1209,7 +1210,7 @@ convertStringBases(char *sb, char *buf, int displayBase, int base) {
 
 	for (i = 0; buf[i] != '\0'; i++) {
 		if (IS_NUMBER(buf[i])) {
-			char  numberString[256];
+			char  numberString[CALC_STRING_SIZE];
 			double num;
 			int j = 0;
 
