@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusT.c
  *
- * Copyright 2009 - 2013  David A. Bagley, bagleyd@tux.org
+ * Copyright 2009 - 2013  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -1454,6 +1454,11 @@ static Boolean pendingUpdate(AbacusWidget w, char * buffer,
 	int line, int aux, int position, int bottomNumber)
 {
 	Boolean done;
+#ifdef OLD_DEBUG
+        (void) printf("pendingUpdate %s, %d, %d, %d, %d, %d, %d\n",
+                buffer, line, aux, position, bottomNumber,
+	        w->abacus.lower, w->abacus.upper);
+#endif
 
 	(void) sprintf(buffer, "For rail %d", position);
 	if (w->abacus.lower == 0 && w->abacus.upper == 0 &&
