@@ -100,7 +100,7 @@ extern void PLAY_SOUND_MMOV(char* fileName);
 
 #ifdef USE_VMSPLAY
 /*-
- * Jouk Jansen <joukj@hrem.stm.tudelft.nl> contributed this
+ * Jouk Jansen <joukj AT hrem.nano.tudelft.nl> contributed this
  * which he found at http://axp616.gsi.de:8080/www/vms/mzsw.html
  *
  * quick hack for sounds in xlockmore on VMS
@@ -245,7 +245,7 @@ play_sound(char *fileName)
 }
 
 /* Found this snippet from modes/glx/xpm-image.c by way of
-   Jamie Zawinski <jwz@jwz.org> Copyright 1998 */
+   Jamie Zawinski <jwz AT jwz.org> Copyright 1998 */
 static int
 bigendian (void)
 {
@@ -279,19 +279,19 @@ sound_esd_load_sample(char *file)
 	int in_format, in_width, in_channels, frame_count;
 	int bytes_per_frame;
 	double in_rate;
-	char *origfile = strdup(file ? file : "");
+	char *origfile;
 	char fullfile[MAXPATHLEN];
 
-#ifdef DEBUG
-	(void) fprintf(stderr, "sound_esd_load_sample: %s\n", origfile);
-#endif
-
 	s = EsdSamplesList;
+#ifdef DEBUG
+	(void) fprintf(stderr, "sound_esd_load_sample: %s\n", s->file);
+#endif
 	while (s && strcmp(file, s->file))
 		s = s->next;
 	if (s && !strcmp(file, s->file))
 		return s;
 
+	origfile = strdup(file ? file : "" );
 #ifdef DEBUG
 	(void) fprintf(stderr,
 		"sound_esd_load_sample: sample not loaded: loading %s\n",
@@ -310,22 +310,25 @@ sound_esd_load_sample(char *file)
 	if (stat(file, &stbuf) < 0) {
 		(void) fprintf(stderr,
 			"Can not find the sound file %s\n", file);
+		free(origfile);
 		return NULL;
 	}
 	if (!(in_file = afOpenFile(file, "r", NULL))) {
 		(void) fprintf(stderr,
 			"Can not open sound sample, bad format?\n");
+		free(origfile);
 		return(NULL);
 	}
 	s = EsdSamplesList;
 	if (s) {
-		while (s && s->next)
+		while (s->next)
 			s = s->next;
 		s->next = (EsdSample_t *) malloc(sizeof(EsdSample_t));
 		if (!s->next) {
 			(void) fprintf(stderr,
 				"Can not allocate sample data.\n");
 			(void) afCloseFile(in_file);
+			free(origfile);
 			return NULL;
 		}
 		s = s->next;
@@ -336,6 +339,7 @@ sound_esd_load_sample(char *file)
 			(void) fprintf(stderr,
 				"Can not allocate sample data.\n");
 			(void) afCloseFile(in_file);
+			free(origfile);
 			return NULL;
 		}
 		EsdSamplesList = s;
@@ -347,7 +351,7 @@ sound_esd_load_sample(char *file)
 	afGetSampleFormat(in_file, AF_DEFAULT_TRACK, &in_format, &in_width);
 	(void) afSetVirtualByteOrder(in_file, AF_DEFAULT_TRACK, (bigendian()) ?
 		AF_BYTEORDER_BIGENDIAN : AF_BYTEORDER_LITTLEENDIAN);
-	s->file = strdup(origfile);
+	s->file = origfile;
 	s->rate = 44100;
 	s->format = ESD_STREAM | ESD_PLAY;
 	s->samples = 0;
